<?php

/**
 * @file
 * Contains page callbacks for the Entity Abuse module.
 */

/**
 * Ajax page callback for adding new abuse.
 */
function entity_abuse_add_abuse_ajax_callback($entity_type, $entity_id) {

  $commands[] = array();

  // Ensure that such entity exists.
  $entity = entity_load($entity_type, array($entity_id));
  if (empty($entity)) {
    $commands[] = ajax_command_alert(t('There is no such entity in the system.'));
  }
  else {

    entity_abuse_include('api');
    $user_has_complain = entity_abuse_user_has_complain($entity_id, $entity_type);

    if ($user_has_complain) {

      drupal_set_message(t('You already complained on this content.'), 'warning');

      entity_abuse_include('ajax');
      $commands[] = entity_abuse_ajax_command_open_dialog(theme('status_messages'));
    }
    else {

      $reason_field_status = variable_get('entity_abuse_reason_field', ENTITY_ABUSE_REASON_FIELD_OPTIONAL);
      if ($reason_field_status == ENTITY_ABUSE_REASON_FIELD_DISABLED) {

        entity_abuse_include('api');
        $result = entity_abuse_add($entity_id, $entity_type);

        // Set message about results of adding abuse.
        if ($result) {
          drupal_set_message(t('Your complain recieved. Thank you!'));
        }
        else {
          drupal_set_message(t('You complain was not added. Probably, you already complained for this content.'), 'warning');
        }

        entity_abuse_include('ajax');
        $commands[] = entity_abuse_ajax_command_open_dialog(theme('status_messages'));
      }
      else {
        entity_abuse_include('forms');
        $form = drupal_get_form('entity_abuse_submit_form', $entity_type, $entity_id);

        entity_abuse_include('ajax');
        $commands[] = entity_abuse_ajax_command_open_dialog(render($form));
      }
    }

    // Replace all links with abuse to this entity with link to cancel abuse.
    $abuse_link = entity_abuse_get_abuse_link($entity_id, $entity_type, TRUE);
    $abuse_link_selector = '.entity-abuse-' . $entity_type . '-' . $entity_id;
    $commands[] = ajax_command_replace($abuse_link_selector, render($abuse_link));
  }

  return array('#type' => 'ajax', '#commands' => $commands);
}

/**
 * Ajax page callback for canceling existing abuse.
 */
function entity_abuse_cancel_abuse_ajax_callback($entity_type, $entity_id) {
  $commands[] = array();

  // Ensure that such entity exists.
  $entity = entity_load($entity_type, array($entity_id));
  if (empty($entity)) {
    $commands[] = ajax_command_alert(t('There is no such entity in the system.'));
  }
  else {

    entity_abuse_include('api');
    $user_has_complain = entity_abuse_user_has_complain($entity_id, $entity_type);

    if ($user_has_complain) {

      // Cancel one abuse for the content.
      entity_abuse_include('api');
      entity_abuse_cancel($entity_id, $entity_type);

      drupal_set_message(t('Your complain was canceled.'));
    }
    else {
      drupal_set_message(t('You didn\'t complain for this content.'), 'warning');
    }

    // Replace all links with abuse to this entity with link to cancel abuse.
    $abuse_link = entity_abuse_get_abuse_link($entity_id, $entity_type, TRUE);
    $abuse_link_selector = '.entity-abuse-' . $entity_type . '-' . $entity_id;
    $commands[] = ajax_command_replace($abuse_link_selector, render($abuse_link));

    entity_abuse_include('ajax');
    $commands[] = entity_abuse_ajax_command_open_dialog(theme('status_messages'), array('title' => t('Cancel complain')));
  }

  return array('#type' => 'ajax', '#commands' => $commands);
}
